API docs for “spamfighter.api.domain.test.test_get.DomainGetCommandTestCase”

# Class s.a.d.t.t.DomainGetCommandTestCase(unittest.TestCase):

Part of spamfighter.api.domain.test.test_get View Source View In Hierarchy

Тест на `spamfighter.api.domain.get.DomainGetCommand`.

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testRunNonexistent | Undocumented
Method | testRunSimpleValue | Undocumented
Method | testRunObjectValue | Undocumented

def setUp(self): (source)
Undocumented
def tearDown(self): (source)
Undocumented
def testRunNonexistent(self): (source)
Undocumented
def testRunSimpleValue(self): (source)
Undocumented
def testRunObjectValue(self): (source)
Undocumented